@@ -1,3 +1,4 @@
+import re
 import json
 import logging
 
@@ -141,10 +142,29 @@ class JsonEncoder(Encoder):
     extension = 'json'
 
     def encode(self, data):
-        return json.dumps(data)
+        to_upper = lambda match: match.group(1).upper()
+        return json.dumps(self.pass_through_all_keys('_(.)', to_upper, data))
 
     def decode(self, data):
-        return json.loads(data)
+        data = json.loads(data)
+        to_lower = lambda match: \
+                '{0}_{1}'.format(match.group(1), match.group(2).lower())
+        return self.pass_through_all_keys('([a-z])([A-Z])', to_lower, data)
+
+    def pass_through_all_keys(self, pattern, function, data):
+        if isinstance(data, dict):
+            new_dict = {}
+            for key, value in data.items():
+                new_key = re.sub(pattern, function, key)
+                new_dict[new_key] = self.pass_through_all_keys(
+                        pattern, function, value)
+            return new_dict
+        if isinstance(data, (list, tuple)):
+            for i in range(len(data)):
+                data[i] = self.pass_through_all_keys(
+                        pattern, function, data[i])
+            return data
+        return data
 
 
 class JsonpEncoder(JsonEncoder):
